import os
import sys


def main():
    print(sys.argv)
    if len(sys.argv) > 1:
        filename = sys.argv[1]
        extract(filename)
    else:
        print("tarun file_name")

def extract(filename):
    name = filename.split(".")
    if "tar" in name and len(name) == 1:
        os.system("tar -xvf %s" %filename)
    elif ("tar" in name and "gz" in name) or "tgz" in name:
        os.system("tar -zxvf %s" %filename)
    elif "gz" in name:
        os.system("gunzip %s" %filename)
    elif "bz2" in name:
        os.system("bzip2 -d %s" %filename)
    elif "bz" in name:
        os.system("bunzip2 -d %s" %filename)
    elif "tar" in name and "bz" in name:
        os.system("tar jxvf %s" %filename)
    elif ("Z" or "z") in name:
        os.system("uncompress %s" %filename)
    elif ("tar" and "Z" in name ) or ("tar" and "z" in name):
        os.system("tar Zxvf %s" %filename)
    elif "zip" in name:
        os.system("unzip %s" %filename)






from setuptools import setup
with open("readme.md", "r") as fh:
    long_description = fh.read()

setup(
    name='tarun',
    version='0.1.2',
    packages=['tarun'],
    url='https://github.com/wangyu190810/tarun',
    license='MIT',
    author='22too',
    entry_points={
            "console_scripts":"""
                tarun = tarun.run:main
            """,
        },
    long_description=long_description,
    long_description_content_type="text/markdown",
    author_email='info@22too.com',
    description='Extract many style file',
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
)
